Learn R Programming

ggm (version 0.5)

is.Gident: G-identifiability of an UG

Description

Tests if an undirected graph is G-identifiable.

Usage

is.Gident(gmat)

Arguments

gmat
a symmetric matrix with dimnames representing the edge matrix of an undirected graph

Value

  • a logical value, TRUE if the graph is G-identifiable and FALSE if it is not.

Details

An undirected graph is G-identifiable if every connected component of the complementary graph contains an odd cycle (cfr. Stanghellini and Wermuth, 2003). The algorithm used follows suggestions by Tarantola and Vicard (2002).

References

Stanghellini, E. & Wermuth, N. (2003). On the identification of directed acyclic graph models with one hidden variable. Submitted and available at http://psystat.sowi.uni-mainz.de. Stanghellini, E. (1997). Identification of a single-factor model using graphical Gaussian rules. Biometrika, 87, 199--205.

Tarantola, C. & Vicard, P. (2002). Spanning trees and identifiability of a single-factor model. Statistical Methods & Applications, 11, 139--152. Vicard, P. (2000). On the identification of a single-factor model with correlated residuals. Biometrika, 87, 199--205.

See Also

UG, cycleMatrix

Examples

Run this code
## A not G-identifiable UG
G1 <- UG(~ a*b + u*v)
is.Gident(G1)
## G-identifiable UG
G2 <- UG(~ a + b + u*v)
is.Gident(G2)

Run the code above in your browser using DataLab