## A model for the sample covariance matrix of the
## mathematics marks (cfr. Whittaker, 1990)
data(marks)
V <- cov(marks) * 87 / 88
## A butterfly concentration graph
fitUg(UG(~ mec*vec*alg + alg*ana*sta),V , n=88)
## Correlations among four strategies to cope with stress for
## 72 students. Cfr. Cox & Wermuth (1996), p. 73.
## Y = cognitive avoidance
## X = vigilance
## V = blunting
## U = monitoring
R <- matrix(c(
1.00, -0.20, 0.46, 0.01,
-0.20, 1.00, 0.00, 0.47,
0.46, 0.00, 1.00, -0.15,
0.01, 0.47, -0.15, 1.00), 4, 4)
nam <- c("Y", "X", "V", "U")
dimnames(R) <- list(nam, nam)
## A chordless 4-cycle covariance graph
gr <- UG(~ Y*X + X*U + U*V + V*Y)
fitUg(gr, R, 72, cov=TRUE)Run the code above in your browser using DataLab