ggm: The package `ggm': summary information
Description
This package provides functions for defining and manipulating graphs
and for fitting graphical Gaussian models.Functions
The main functions can be classified as follows.
- Functions for defining graphs (undirected, directed acyclic,
ancestral graphs):
UG,DAG,makeAG; - Functions for doing graph operations (parents, boundary,
cliques, connected components, fundamental cycles, d-separation):
pa,bd,cliques,conComp,fundCycles,dSep; - Function for finding covariance and concentration graphs
induced by marginalization and conditioning:
inducedCovGraph,inducedConGraph; - Functions for finding multivariate regression graphs and chain
graphs induced by marginalization and conditioning:
inducedRegGraph,inducedChainGraph,inducedDAG; - Functions for fitting by ML Gaussian DAGs, concentration graphs,
covariance graphs and ancestral graphs:
fitDag,fitConGraph,fitCovGraph,fitAncestralGraph; - Functions for testing several conditional independences:
shipley.test; - Functions for checking global identification
of DAG Gaussian models with one
latent variable (Stanghellini-Vicard's condition for concentration graphs,
new sufficient conditions for DAGs):
isGident,checkIdent; - Functions for fitting Gaussian DAG models with one latent variable:
fitDagLatent.
The package is intended as a contribution to the gR-project
derscribed by Lauritzen (2002).Authors
Giovanni M. Marchetti, Dipartimento di Statistica ``G. Parenti''.
Universit`a di Firenze, Italy;
Mathias Drton, Department of Statistics, University of Chicago, USA.Acknowledgements
Many thanks to Fulvia Pennoni for testing some of
the functions, to Elena Stanghellini for discussion and
examples and to Claus Dethlefsen and Jens Henrik Badsberg for
suggestions and corrections. Helpful discussions with Nanny Wermuth,
are gratefully acknowledged. Thanks also to Michael Perlman and
Thomas Richardson.Giovanni Marchetti has been supported by MIUR, Italy, under grant
scheme PRIN 2002, and Mathias Drton has been supported by NSF grant
DMS-9972008 and University of Washington RRF grant 65-3010.
References
Lauritzen, S. L. (2002). gRaphical Models in R.
R News, 3(2)39.